##  Reordering Sections and Subsections
You can define the order in which sections and subsections appear on a fact sheet. To do that, select a section or subsection, navigate to the Change position tab on the right-side panel, adjust the order as needed, then save the changes.
![Adjusting the Position of a Subsection](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754f6007a441014add093a87a036800_LowRes.png)
Adjusting the Position of a Subsection on a Fact Sheet
